spqrtree
========

A pure Python SPQR-tree implementation for biconnected graphs.

**spqrtree** decomposes a biconnected graph into its triconnected
components and organizes them as an SPQR-tree, a classical data
structure in graph theory used for planarity testing, graph drawing,
and network analysis.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   intro
   spqrtree
   changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
